@@ -1,7 +1,6 @@
 from datetime import datetime
-from typing import Any, Optional
-
 from pydantic import BaseModel, Field
+from typing import Any, Literal, Optional
 
 from nonebot.typing import overrides
 
@@ -34,9 +33,12 @@ class MessageEvent(Event):
     message_chain: MessageChain = Field(alias='messageChain')
     source: Optional[MessageSource] = None
     sender: Any
-    to_quote: bool = False
     quote: Optional[MessageQuote] = None
 
+    @overrides(Event)
+    def get_type(self) -> Literal["message"]:  # noqa
+        return 'message'
+
     @overrides(Event)
     def get_message(self) -> MessageChain:
         return self.message_chain
